@@ -1,8 +1,6 @@
 package main
 
 import (
-	"os"
-
 	acorn "github.com/acorn-io/acorn/pkg/cli"
 	"github.com/acorn-io/acorn/pkg/version"
 	"github.com/rancher/wrangler/pkg/signals"
@@ -17,7 +15,5 @@ func main() {
 	cmd.InitDefaultVersionFlag()
 
 	ctx := signals.SetupSignalContext()
-	if err := cmd.ExecuteContext(ctx); err != nil {
-		os.Exit(1)
-	}
+	acorn.RunAndHandleError(ctx, cmd)
 }
