@@ -4,33 +4,35 @@ import (
 	"fmt"
 
 	cli "github.com/acorn-io/acorn/pkg/cli/builder"
-	"github.com/acorn-io/acorn/pkg/client"
 	"github.com/spf13/cobra"
 )
 
-func NewContainerDelete() *cobra.Command {
-	cmd := cli.Command(&ContainerDelete{}, cobra.Command{
+func NewContainerDelete(c CommandContext) *cobra.Command {
+	cd := &ContainerDelete{client: c.ClientFactory}
+	cmd := cli.Command(cd, cobra.Command{
 		Use: "kill [CONTAINER_NAME...]",
 		Example: `
 acorn container kill app-name.containername-generated-hash`,
-		SilenceUsage: true,
-		Short:        "Delete a container",
-		Aliases:      []string{"rm"},
+		SilenceUsage:      true,
+		Short:             "Delete a container",
+		Aliases:           []string{"rm"},
+		ValidArgsFunction: newCompletion(c.ClientFactory, containersCompletion).complete,
 	})
 	return cmd
 }
 
 type ContainerDelete struct {
+	client ClientFactory
 }
 
 func (a *ContainerDelete) Run(cmd *cobra.Command, args []string) error {
-	client, err := client.Default()
+	c, err := a.client.CreateDefault()
 	if err != nil {
 		return err
 	}
 
 	for _, container := range args {
-		replicaDelete, err := client.ContainerReplicaDelete(cmd.Context(), container)
+		replicaDelete, err := c.ContainerReplicaDelete(cmd.Context(), container)
 		if err != nil {
 			return fmt.Errorf("deleting %s: %w", container, err)
 		}
