@@ -6,8 +6,8 @@ import (
 	"github.com/spf13/cobra"
 )
 
-func NewController() *cobra.Command {
-	return cli.Command(&Controller{}, cobra.Command{
+func NewController(c CommandContext) *cobra.Command {
+	return cli.Command(&Controller{client: c.ClientFactory}, cobra.Command{
 		Use:          "controller",
 		SilenceUsage: true,
 		Hidden:       true,
@@ -17,6 +17,7 @@ func NewController() *cobra.Command {
 }
 
 type Controller struct {
+	client ClientFactory
 }
 
 func (s *Controller) Run(cmd *cobra.Command, args []string) error {
