@@ -4,11 +4,12 @@ import (
 	apiv1 "github.com/acorn-io/acorn/pkg/apis/api.acorn.io/v1"
 	cli "github.com/acorn-io/acorn/pkg/cli/builder"
 	"github.com/acorn-io/acorn/pkg/install"
+	"github.com/acorn-io/acorn/pkg/system"
 	"github.com/spf13/cobra"
 )
 
-func NewInstall() *cobra.Command {
-	return cli.Command(&Install{}, cobra.Command{
+func NewInstall(c CommandContext) *cobra.Command {
+	return cli.Command(&Install{client: c.ClientFactory}, cobra.Command{
 		Use: "install [flags]",
 		Example: `
 acorn install`,
@@ -29,10 +30,11 @@ type Install struct {
 	ControllerReplicas *int `usage:"acorn-controller deployment replica count"`
 
 	apiv1.Config
+	client ClientFactory
 }
 
 func (i *Install) Run(cmd *cobra.Command, args []string) error {
-	var image = install.DefaultImage()
+	var image = system.DefaultImage()
 	if i.Image != "" {
 		image = i.Image
 	}
