@@ -4,26 +4,28 @@ import (
 	"fmt"
 
 	cli "github.com/acorn-io/acorn/pkg/cli/builder"
-	"github.com/acorn-io/acorn/pkg/client"
 	"github.com/spf13/cobra"
 )
 
-func NewSecretDelete() *cobra.Command {
-	cmd := cli.Command(&SecretDelete{}, cobra.Command{
+func NewSecretDelete(c CommandContext) *cobra.Command {
+	cmd := cli.Command(&SecretDelete{client: c.ClientFactory}, cobra.Command{
 		Use: "rm [SECRET_NAME...]",
 		Example: `
 acorn secret rm my-secret`,
-		SilenceUsage: true,
-		Short:        "Delete a secret",
+		SilenceUsage:      true,
+		Short:             "Delete a secret",
+		ValidArgsFunction: newCompletion(c.ClientFactory, secretsCompletion).complete,
 	})
 	return cmd
 }
 
 type SecretDelete struct {
+	client ClientFactory
 }
 
 func (a *SecretDelete) Run(cmd *cobra.Command, args []string) error {
-	client, err := client.Default()
+
+	client, err := a.client.CreateDefault()
 	if err != nil {
 		return err
 	}
