@@ -6,10 +6,11 @@ import (
 	apiv1 "github.com/acorn-io/acorn/pkg/apis/api.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/client/term"
 	"github.com/acorn-io/acorn/pkg/scheme"
+	"github.com/sirupsen/logrus"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
-func (c *client) execContainer(ctx context.Context, container *apiv1.ContainerReplica, args []string, tty bool, opts *ContainerReplicaExecOptions) (*term.ExecIO, error) {
+func (c *DefaultClient) execContainer(ctx context.Context, container *apiv1.ContainerReplica, args []string, tty bool, opts *ContainerReplicaExecOptions) (*term.ExecIO, error) {
 	req := c.RESTClient.Get().
 		Namespace(container.Namespace).
 		Resource("containerreplicas").
@@ -21,6 +22,7 @@ func (c *client) execContainer(ctx context.Context, container *apiv1.ContainerRe
 			DebugImage: opts.DebugImage,
 		}, scheme.ParameterCodec)
 
+	logrus.Debugf("Exec URL: %s", req.URL().String())
 	conn, err := c.Dialer.DialContext(ctx, req.URL().String(), nil)
 	if err != nil {
 		return nil, err
@@ -29,7 +31,7 @@ func (c *client) execContainer(ctx context.Context, container *apiv1.ContainerRe
 	return conn.ToExecIO(tty), nil
 }
 
-func (c *client) ContainerReplicaExec(ctx context.Context, containerName string, args []string, tty bool, opts *ContainerReplicaExecOptions) (*term.ExecIO, error) {
+func (c *DefaultClient) ContainerReplicaExec(ctx context.Context, containerName string, args []string, tty bool, opts *ContainerReplicaExecOptions) (*term.ExecIO, error) {
 	if containerName == "_" && opts != nil && opts.DebugImage != "" {
 		return c.execContainer(ctx, &apiv1.ContainerReplica{
 			ObjectMeta: metav1.ObjectMeta{
