@@ -10,7 +10,7 @@ import (
 	kclient "sigs.k8s.io/controller-runtime/pkg/client"
 )
 
-func (c *client) VolumeList(ctx context.Context) (result []apiv1.Volume, _ error) {
+func (c *DefaultClient) VolumeList(ctx context.Context) (result []apiv1.Volume, _ error) {
 	vols := &apiv1.VolumeList{}
 	err := c.Client.List(ctx, vols, &kclient.ListOptions{
 		Namespace: c.Namespace,
@@ -29,7 +29,7 @@ func (c *client) VolumeList(ctx context.Context) (result []apiv1.Volume, _ error
 	return vols.Items, nil
 }
 
-func (c *client) VolumeGet(ctx context.Context, name string) (*apiv1.Volume, error) {
+func (c *DefaultClient) VolumeGet(ctx context.Context, name string) (*apiv1.Volume, error) {
 	vol := &apiv1.Volume{}
 	return vol, c.Client.Get(ctx, kclient.ObjectKey{
 		Name:      name,
@@ -37,7 +37,7 @@ func (c *client) VolumeGet(ctx context.Context, name string) (*apiv1.Volume, err
 	}, vol)
 }
 
-func (c *client) VolumeDelete(ctx context.Context, name string) (*apiv1.Volume, error) {
+func (c *DefaultClient) VolumeDelete(ctx context.Context, name string) (*apiv1.Volume, error) {
 	// get first to ensure the namespace matches
 	v, err := c.VolumeGet(ctx, name)
 	if apierror.IsNotFound(err) {
