@@ -13,10 +13,11 @@ import (
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/condition"
 	"github.com/acorn-io/acorn/pkg/config"
-	"github.com/acorn-io/acorn/pkg/install"
+	"github.com/acorn-io/acorn/pkg/images"
 	"github.com/acorn-io/acorn/pkg/labels"
 	"github.com/acorn-io/acorn/pkg/ports"
-	"github.com/acorn-io/acorn/pkg/pull"
+	"github.com/acorn-io/acorn/pkg/system"
+	"github.com/acorn-io/acorn/pkg/tags"
 	"github.com/acorn-io/baaah/pkg/apply"
 	"github.com/acorn-io/baaah/pkg/router"
 	"github.com/acorn-io/baaah/pkg/typed"
@@ -31,6 +32,24 @@ import (
 	kclient "sigs.k8s.io/controller-runtime/pkg/client"
 )
 
+func RemoveLabelsAndAnnotationsConfig(h router.Handler) router.Handler {
+	return router.HandlerFunc(func(req router.Request, resp router.Response) error {
+		appInstance := req.Object.(*v1.AppInstance)
+		cfg, err := config.Get(req.Ctx, req.Client)
+		if err != nil {
+			return err
+		}
+
+		// Note that IgnoreUserLabelsAndAnnotations will not be nil here because
+		// config.Get "completes" the config object to fill in default values.
+		if *cfg.IgnoreUserLabelsAndAnnotations {
+			req.Object = labels.RemoveUserDefined(appInstance)
+		}
+
+		return h.Handle(req, resp)
+	})
+}
+
 func DeploySpec(req router.Request, resp router.Response) (err error) {
 	appInstance := req.Object.(*v1.AppInstance)
 	status := condition.Setter(appInstance, resp, v1.AppInstanceConditionDefined)
@@ -43,7 +62,7 @@ func DeploySpec(req router.Request, resp router.Response) (err error) {
 		}
 	}()
 
-	tag, err := pull.GetTag(req.Ctx, req.Client, appInstance.Namespace, appInstance.Status.AppImage.ID)
+	tag, err := images.GetRuntimePullableImageReference(req.Ctx, req.Client, appInstance.Namespace, appInstance.Status.AppImage.ID)
 	if err != nil {
 		return err
 	}
@@ -110,12 +129,29 @@ func toEnvFrom(envs []v1.EnvVar) (result []corev1.EnvFromSource) {
 	return
 }
 
-func toEnv(envs []v1.EnvVar, appEnv []v1.NameValue) (result []corev1.EnvVar) {
+func translateEnvValue(app *v1.AppInstance, value string) string {
+	switch value {
+	case "${app.image}":
+		if tags.IsLocalReference(app.Status.AppImage.ID) {
+			return app.Status.AppImage.ID
+		} else if app.Status.AppImage.ID != "" && app.Status.AppImage.Digest != "" {
+			tag, err := name.NewTag(app.Status.AppImage.ID)
+			if err == nil {
+				return tag.Digest(app.Status.AppImage.Digest).String()
+			}
+		}
+	case "${app.namespace}":
+		return app.Namespace
+	}
+	return value
+}
+
+func toEnv(app *v1.AppInstance, envs []v1.EnvVar, appEnv []v1.NameValue) (result []corev1.EnvVar) {
 	for _, env := range envs {
 		if env.Secret.Name == "" {
 			result = append(result, corev1.EnvVar{
 				Name:  env.Name,
-				Value: env.Value,
+				Value: translateEnvValue(app, env.Value),
 			})
 		} else {
 			if env.Secret.Key == "" {
@@ -157,7 +193,7 @@ func hasContextDir(container v1.Container) bool {
 	return false
 }
 
-func toContainers(app *v1.AppInstance, tag name.Reference, name string, container v1.Container) ([]corev1.Container, []corev1.Container) {
+func toContainers(req router.Request, app *v1.AppInstance, tag name.Reference, name string, container v1.Container) ([]corev1.Container, []corev1.Container, error) {
 	var (
 		containers     []corev1.Container
 		initContainers []corev1.Container
@@ -166,7 +202,7 @@ func toContainers(app *v1.AppInstance, tag name.Reference, name string, containe
 	if app.Spec.GetDevMode() && hasContextDir(container) {
 		initContainers = append(initContainers, corev1.Container{
 			Name:            "acorn-helper",
-			Image:           install.DefaultImage(),
+			Image:           system.DefaultImage(),
 			Command:         []string{"acorn-helper-init"},
 			ImagePullPolicy: corev1.PullIfNotPresent,
 			VolumeMounts: []corev1.VolumeMount{
@@ -178,9 +214,18 @@ func toContainers(app *v1.AppInstance, tag name.Reference, name string, containe
 		})
 	}
 
-	containers = append(containers, toContainer(app, tag, name, name, container))
+	newContainer, err := toContainer(req, app, tag, name, name, container)
+	if err != nil {
+		return nil, nil, err
+	}
+
+	containers = append(containers, newContainer)
 	for _, entry := range typed.Sorted(container.Sidecars) {
-		newContainer := toContainer(app, tag, name, entry.Key, entry.Value)
+		newContainer, err = toContainer(req, app, tag, name, entry.Key, entry.Value)
+		if err != nil {
+			return nil, nil, err
+		}
+
 		if entry.Value.Init {
 			initContainers = append(initContainers, newContainer)
 		} else {
@@ -188,7 +233,7 @@ func toContainers(app *v1.AppInstance, tag name.Reference, name string, containe
 		}
 	}
 
-	return containers, initContainers
+	return containers, initContainers, nil
 }
 
 func pathHash(parts ...string) string {
@@ -372,14 +417,14 @@ func toProbe(container v1.Container, probeType v1.ProbeType) *corev1.Probe {
 	return nil
 }
 
-func toContainer(app *v1.AppInstance, tag name.Reference, deploymentName, containerName string, container v1.Container) corev1.Container {
-	return corev1.Container{
+func toContainer(req router.Request, app *v1.AppInstance, tag name.Reference, deploymentName, containerName string, container v1.Container) (corev1.Container, error) {
+	containerObject := corev1.Container{
 		Name:           containerName,
-		Image:          pull.ResolveTag(tag, container.Image),
+		Image:          images.ResolveTag(tag, container.Image),
 		Command:        container.Entrypoint,
 		Args:           container.Command,
 		WorkingDir:     container.WorkingDir,
-		Env:            toEnv(container.Environment, app.Spec.Environment),
+		Env:            toEnv(app, container.Environment, app.Spec.Environment),
 		EnvFrom:        toEnvFrom(container.Environment),
 		TTY:            container.Interactive,
 		Stdin:          container.Interactive,
@@ -389,6 +434,26 @@ func toContainer(app *v1.AppInstance, tag name.Reference, deploymentName, contai
 		StartupProbe:   toProbe(container, v1.StartupProbeType),
 		ReadinessProbe: toProbe(container, v1.ReadinessProbeType),
 	}
+
+	resources, err := toResources(req, app, container, containerName)
+	if err != nil {
+		return corev1.Container{}, err
+	}
+
+	if resources != nil {
+		containerObject.Resources = *resources
+	}
+
+	return containerObject, err
+}
+
+func toResources(req router.Request, app *v1.AppInstance, container v1.Container, containerName string) (*corev1.ResourceRequirements, error) {
+	cfg, err := config.Get(req.Ctx, req.Client)
+	if err != nil {
+		return nil, err
+	}
+
+	return v1.MemoryToRequirements(app.Spec.Memory, containerName, container, cfg.WorkloadMemoryDefault, cfg.WorkloadMemoryMaximum)
 }
 
 func containerAnnotations(appInstance *v1.AppInstance, container v1.Container, name string) map[string]string {
@@ -495,7 +560,15 @@ func getRevision(req router.Request, namespace, secretName string) (string, erro
 	if err := req.Get(secret, namespace, secretName); err != nil {
 		return "0", err
 	}
-	return secret.ResourceVersion, nil
+	hash := sha256.New()
+	for _, entry := range typed.Sorted(secret.Data) {
+		hash.Write([]byte(entry.Key))
+		hash.Write([]byte{'\x00'})
+		hash.Write(entry.Value)
+		hash.Write([]byte{'\x00'})
+	}
+	d := hash.Sum(nil)
+	return hex.EncodeToString(d[:]), nil
 }
 
 func getSecretAnnotations(req router.Request, appInstance *v1.AppInstance, container v1.Container) (map[string]string, error) {
@@ -542,7 +615,10 @@ func toDeployment(req router.Request, appInstance *v1.AppInstance, tag name.Refe
 		stateful = isStateful(appInstance, container)
 	)
 
-	containers, initContainers := toContainers(appInstance, tag, name, container)
+	containers, initContainers, err := toContainers(req, appInstance, tag, name, container)
+	if err != nil {
+		return nil, err
+	}
 
 	secretAnnotations, err := getSecretAnnotations(req, appInstance, container)
 	if err != nil {
