@@ -2,11 +2,15 @@ package namespace
 
 import (
 	"context"
+	"fmt"
 	"strings"
 
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
+	hclient "github.com/acorn-io/acorn/pkg/k8sclient"
 	"github.com/acorn-io/acorn/pkg/labels"
 	"github.com/acorn-io/baaah/pkg/router"
+	corev1 "k8s.io/api/core/v1"
+	apierror "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	klabels "k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apiserver/pkg/endpoints/request"
@@ -62,3 +66,22 @@ func Selector(ctx context.Context) klabels.Selector {
 		labels.AcornAppNamespace: nsName,
 	})
 }
+
+func Ensure(ctx context.Context, c client.Client, name string) error {
+	ns := &corev1.Namespace{}
+	err := c.Get(ctx, hclient.ObjectKey{
+		Name: name,
+	}, ns)
+	if apierror.IsNotFound(err) {
+		err := c.Create(ctx, &corev1.Namespace{
+			ObjectMeta: metav1.ObjectMeta{
+				Name: name,
+			},
+		})
+		if err != nil {
+			return fmt.Errorf("unable to create namespace %s: %w", name, err)
+		}
+		return nil
+	}
+	return err
+}
